function [i1,i2] = decision_intervals(qP,qN, alpha,beta);
%decision_intervals - estimate decision intervals given acceptable
%                     false positive and false negative
%
% [i1,i2] = decision_intervals(qP,qN, fp, fn);
%
%   tP,tN - positive/negative scalar score 
%   fp,fn - acceptable false positive/negative
%
%   i1,i2 - output interval 
%                   t > i1  positive
%                   t < i2  negative
%              i1 < t < i2  undecided (go to next stage)
%
%  (assume positive samples have typically higher quality than negative)
%

inl = [ones(size(qP,1),1);zeros(size(qN,1),1)]';
M = [[qP',qN'];inl];

MM = -sortrows(-M')'; 

%alpha = 0.01;
%beta = 0.01;

TP = length(qP); TN = length(qN);

ix = MM(2,:);
np = cumsum(ix); nn = cumsum(~ix);

t = MM(1,:);


r1 = (nn/TN) ./ (np/TP);
ind = find(r1>alpha); ind = ind(1);
i1 = t(ind);

if 0
    figure(1);
    subplot(2,1,1);
    plot(t,nn/TN,'r+-'); hold on
    plot(t,np/TP,'bx-'); hold on
    title('FP');
    xlabel('t');
    legend('n(t)/TN','p(t)/TP','location','northwest')
    grid on
    subplot(2,1,2);
    plot(t,r1); hold on
    plot(i1, r1(ind),'ko');
    grid on
end

%-- 

MM = fliplr(MM);

ix = MM(2,:);%pts3
np = cumsum(ix); nn = cumsum(~ix);

t = MM(1,:);

r2 = (np/TP) ./ (nn/TN);

ind2 = find(r2>beta); ind2 = ind2(1);
i2 = t(ind2);

if 0
    figure(2);
    subplot(2,1,1);
    plot(t,nn/TN,'r+-'); hold on
    plot(t,np/TP,'bx-'); hold on
    title('FN');
    xlabel('t');
    legend('n(t)/TN','p(t)/TP')
    grid on
    subplot(2,1,2); plot(t,r2); hold on
    plot(i2, r2(ind2),'ko');
    grid on
end

% ix = MM(2,:); c = cumsum(ix);
% p = c./(1:length(ix)); %precision
% FP = 1-p;
% 
% ix = ~MM(2,:); c = cumsum(fliplr(ix));
% p_ = c./(1:length(ix)); %imprecision
% FN = 1-p_;
% 
% t = MM(1,:);
% 
