function [A] = laf2H(TC)
%laf2H - converts LAF of tentative correspondences to homography
%
%   TC - (18xn) of [p1,p1',p2,p2',p3,p3'] in homogeneous coordinates
%   A - (6xn) of [a1,...,a6] affine coefficient of the homography mapping
%            
%                [a1, a2, a3] 
%           x' = |a4, a5, a6| x
%                [ 0   0   1]
%

I = ones(3,1);
O = zeros(3);

A = zeros(6,size(TC,2));
for i=1:size(TC,2),
    x = TC([1,7,13],i)./TC([3,9,15],i);
    y = TC([2,8,14],i)./TC([3,9,15],i);
    x_ = TC([4,10,16],i)./TC([6,12,18],i);
    y_ = TC([5,11,17],i)./TC([6,12,18],i);
    M = [x,y,I,O;
         O,x,y,I];
    A(:,i) = inv(M)*[x_;y_];
end


