% This script demonstrates the functionality of the Sequential
% Correspondence Verefication (SCV) in exemplar scenes. It shows
% correspondences selected by SCV algorithm, and also for a reference the 
% same number of correspondences with best SIFT-ratio. 
% ----------------------------------------------------------------------

scene = 'cart';      %name of a scene for demonstration  (try one of these)
%scene = 'cytisus'; 
%scene = 'mullein'; 

alpha = 0.001; %parameters of the Wald's SPRT test 
beta = 0.02;   %lower (e.g. 0.001) -> more precise but slower
               %higher (e.g. 0.05) -> less precise but faster

% ----------------------------------------------------------------------

load(['demo/',scene])
% the file contains:
%   - u ... set of input correspondences to be verified
%   - sift_ratio ... a ratio of first to second closest SIFT descriptors
%                    associated to the correspondence

Il = imread(['demo/',scene,'_0.jpg']); %read the input images 
Ir = imread(['demo/',scene,'_1.jpg']); 

Ill = sum(double(Il),3); %input images converted to gray-scale
Irr = sum(double(Ir),3); %input images converted to gray-scale

load P-SVM_p_3_C=1e-0 %load trained model (pdf+SVM)

tic,
% ----------------------- call verification algorithm 
 L = SCV(Ill,Irr,u,sift_ratio, model, alpha, beta);
% ----------------------- (L is a likelihood-ratio from verification)
toc,

% visualization ---------------------------------------------------------

N = sum(L>1); %number of correspondences found by SCV (by thresholding L)

disp(['Number of input correspondences: ',num2str(size(u,2))]);
disp(['Number of selected correspondences: ',num2str(N)]);

figure(1); clf;  %correspondences by SCV
w=min(size(Il,2),size(Ir,2));
imshow([Il(:,1:w,:); Ir(:,1:w,:)],'InitialMagnification',50); hold on;
[LL,S] = sort(L,'descend'); %sort correspondences according to L
idxs = S(1:N);            %show best N correspondences
%idxs = L>1;             
plot([u([1,4],idxs) , u([7,10],idxs), u([13,16],idxs)],...
    [u(2,idxs) , u(8,idxs), u(14,idxs) ;
    [u(5,idxs) , u(11,idxs), u(17,idxs)]+size(Il,1)]);
set(gcf,'name',[scene,'-SCV']);

figure(2); clf; %correspondences by sift-ratio
imshow([Il(:,1:w,:); Ir(:,1:w,:)],'InitialMagnification',50); hold on;
[SS,S] = sort(sift_ratio,'ascend'); %sort correspondences according to sift_ratio
idxs = S(1:N);
%idxs = sift_ratio<0.8; %standard correspondence selection
plot([u([1,4],idxs) , u([7,10],idxs), u([13,16],idxs)],...
    [u(2,idxs) , u(8,idxs), u(14,idxs) ;
    [u(5,idxs) , u(11,idxs), u(17,idxs)]+size(Il,1)]);
set(gcf,'name',[scene,'-sift_ratio']);



